@@ -48,16 +48,13 @@ namespace Ogre {
     class _OgreExport GpuProgramManager : public ResourceManager, public Singleton<GpuProgramManager>
     {
         // silence warnings
-        using ResourceManager::createImpl;
         using ResourceManager::load;
-        using ResourceManager::getResourceByName;
     public:
 
         typedef std::set<String> SyntaxCodes;
         typedef std::map<String, GpuSharedParametersPtr> SharedParametersMap;
 
         typedef MemoryDataStreamPtr Microcode;
-        OGRE_DEPRECATED typedef std::map<String, Microcode> MicrocodeMap;
 
     protected:
 
@@ -68,10 +65,15 @@ namespace Ogre {
             
         static String addRenderSystemToName( const String &  name );
 
+        /// Generic create method
+        Resource* createImpl(const String& name, ResourceHandle handle,
+            const String& group, bool isManual, ManualResourceLoader* loader,
+            const NameValuePairList* createParams);
+
         /// Specialised create method with specific parameters
         virtual Resource* createImpl(const String& name, ResourceHandle handle, 
             const String& group, bool isManual, ManualResourceLoader* loader,
-            GpuProgramType gptype, const String& syntaxCode) = 0;
+            GpuProgramType gptype, const String& syntaxCode);
     public:
         GpuProgramManager();
         virtual ~GpuProgramManager();
@@ -174,7 +176,10 @@ namespace Ogre {
         @param preferHighLevelPrograms If set to true (the default), high level programs will be
             returned in preference to low-level programs.
         */
-        ResourcePtr getResourceByName(const String& name, const String& group OGRE_RESOURCE_GROUP_INIT, bool preferHighLevelPrograms = true);
+        ResourcePtr getResourceByName(const String& name, const String& group, bool preferHighLevelPrograms);
+
+        /// @overload
+        ResourcePtr getResourceByName(const String& name, const String& group OGRE_RESOURCE_GROUP_INIT);
 
         /** Create a new set of shared parameters, which can be used across many 
             GpuProgramParameters objects of different structures.
@@ -209,25 +214,11 @@ namespace Ogre {
         */
         bool isMicrocodeAvailableInCache(uint32 id) const;
 
-        /// @deprecated
-        OGRE_DEPRECATED bool isMicrocodeAvailableInCache(String name) const
-        {
-            name = addRenderSystemToName(name);
-            return isMicrocodeAvailableInCache(FastHash(name.c_str(), name.size()));
-        }
-
         /** Returns a microcode for a program from the microcode cache.
         @param id The name of the program.
         */
         const Microcode& getMicrocodeFromCache(uint32 id) const;
 
-        /// @deprecated
-        OGRE_DEPRECATED const Microcode& getMicrocodeFromCache(String name) const
-        {
-            name = addRenderSystemToName(name);
-            return getMicrocodeFromCache(FastHash(name.c_str(), name.size()));
-        }
-
         /** Creates a microcode to be later added to the cache.
         @param size The size of the microcode in bytes
         */
@@ -239,25 +230,11 @@ namespace Ogre {
         */
         void addMicrocodeToCache(uint32 id, const Microcode& microcode);
 
-        /// @deprecated
-        OGRE_DEPRECATED void addMicrocodeToCache(String name, const Microcode& microcode)
-        {
-            name = addRenderSystemToName(name);
-            addMicrocodeToCache(FastHash(name.c_str(), name.size()), microcode);
-        }
-
         /** Removes a microcode for a program from the microcode cache.
         @param id The name of the program.
         */
         void removeMicrocodeFromCache(uint32 id);
 
-        /// @deprecated
-        OGRE_DEPRECATED void removeMicrocodeFromCache(String name)
-        {
-            name = addRenderSystemToName(name);
-            removeMicrocodeFromCache(FastHash(name.c_str(), name.size()));
-        }
-
         /** Saves the microcode cache to disk.
         @param stream The destination stream
         */
