@@ -92,17 +92,10 @@ namespace Ogre {
         // statecaches are per context
         GL3PlusStateCacheManager* mStateCacheManager;
 
-        GLSLShaderManager *mShaderManager;
+        GpuProgramManager *mShaderManager;
         GLSLShaderFactory* mGLSLShaderFactory;
         HardwareBufferManager* mHardwareBufferManager;
 
-        /** Manager object for creating render textures.
-            Direct render to texture via FBO is preferable
-            to pbuffers, which depend on the GL support used and are generally
-            unwieldy and slow. However, FBO support for stencil buffers is poor.
-        */
-        GLRTTManager *mRTTManager;
-
         /** These variables are used for caching RenderSystem state.
             They are cached because OpenGL state changes can be quite expensive,
             which is especially important on mobile or embedded systems.
@@ -147,7 +140,7 @@ namespace Ogre {
 
         const String& getName(void) const;
 
-        RenderWindow* _initialise(bool autoCreateWindow, const String& windowTitle = "OGRE Render Window");
+        void _initialise() override;
 
         virtual RenderSystemCapabilities* createRenderSystemCapabilities() const;
 
@@ -166,10 +159,6 @@ namespace Ogre {
         /// @copydoc RenderSystem::_createDepthBufferFor
         DepthBuffer* _createDepthBufferFor( RenderTarget *renderTarget );
 
-        /// Mimics D3D9RenderSystem::_getDepthStencilFormatFor, if no FBO RTT manager, outputs GL_NONE
-        void _getDepthStencilFormatFor( PixelFormat internalColourFormat, GLenum *depthFormat,
-                                        GLenum *stencilFormat );
-
         /// @copydoc RenderSystem::createMultiRenderTarget
         virtual MultiRenderTarget * createMultiRenderTarget(const String & name);
 
@@ -185,10 +174,6 @@ namespace Ogre {
 
         void _setTextureAddressingMode(size_t stage, const Sampler::UVWAddressingMode& uvw);
 
-        void _setTextureBorderColour(size_t stage, const ColourValue& colour);
-
-        void _setTextureMipmapBias(size_t unit, float bias);
-
         void _setLineWidth(float width);
 
         void _setViewport(Viewport *vp);
@@ -227,12 +212,6 @@ namespace Ogre {
 
         void _setTextureUnitFiltering(size_t unit, FilterType ftype, FilterOptions filter);
 
-        void _setTextureUnitCompareFunction(size_t unit, CompareFunction function);
-
-        void _setTextureUnitCompareEnabled(size_t unit, bool compare);
-
-        void _setTextureLayerAnisotropy(size_t unit, unsigned int maxAnisotropy);
-
         void _dispatchCompute(const Vector3i& workgroupDim);
 
         void _render(const RenderOperation& op);
@@ -299,9 +278,6 @@ namespace Ogre {
         /// @copydoc RenderSystem::getDisplayMonitorCount
         unsigned int getDisplayMonitorCount() const;
 
-        /// @copydoc RenderSystem::hasAnisotropicMipMapFilter
-        virtual bool hasAnisotropicMipMapFilter() const { return false; }
-
         /// @copydoc RenderSystem::beginProfileEvent
         virtual void beginProfileEvent( const String &eventName );
 
